@@ -11,6 +11,7 @@
 import serial
 import termios
 import os
+import sys
 import platform
 import re
 from types import StringType, UnicodeType, IntType
@@ -236,8 +237,8 @@ class Modem:
             return []
         try:
             lines = self.serial.readlines()
-        except OSError, err:
-            self.log( err )
+        except:
+            self.log(sys.exc_info()[1])
             self.close()
             self.ERROR = True
             return []
@@ -958,7 +959,7 @@ class Modem:
                     r['message'] = pdu.text
                 r['msisdn'] = pdu.number
                 r['time'] = '%s+0' % pdu.date
-                self.log('TERIMA SMS %s' % r)
+                self.log('Receive SMS %s' % r)
             else:
                 self.smsFormat == SMS_TEXT
         self.sms[index] = dict(r)
@@ -1024,7 +1025,7 @@ class Modem:
             self.sms[index]['msisdn'] = pdu.number
             self.sms[index]['time'] = '%s+0' % pdu.date
             self.sms[index]['message'] = pdu.text
-            self.log('TERIMA %s' % self.sms[index])
+            self.log('Receive %s' % self.sms[index])
 
         def set_sms():
             if self.smsFormat == SMS_TEXT:
@@ -1042,7 +1043,7 @@ class Modem:
         s = ''
         while True:
             for line in self.readlines():
-                if not index and line.strip() in ['OK','ERROR']: # kosong ?
+                if not index and line.strip() in ['OK','ERROR']: # empty ?
                     return self.unbusy(self.sms)
                 s += line
                 if s[-EOF_COUNT:] == EOF_SIGN: # output berakhir ?
@@ -1429,7 +1430,7 @@ def operator():
 def getsms( DIR ):
     m.getIMEI()
     m.getsms()
-    show(m.sms)
+    #show(m.sms)
     for i in m.sms.keys():
         content = 'imei: %s\ngroup: %s' % (
             m.card['imei'], m.sms[i]['group'])
