@@ -1,3 +1,6 @@
+# Default country code
+default_country_code = 62
+
 # AT command timeout in second
 timeout = 30
 
@@ -18,15 +21,15 @@ init_sms = {
     'MF110': '2,1,0,0,0',
     }
 
-# AT+CSCA=<smsc>
-# Dictionary diisi key = imei chip, value = SMS center
+# Spesific SMS center (AT+CSCA=<smsc>).
+# The key is IMEI/IMSI SIM card, and the value is SMS center.
 smsc = {'510011130802951': '+62816124'}
 
 memory_sms = {
     'Billionton': ['MT', 'SM'], # machine and sim memory
     }
 
-# GSM biasanya bisa PDU mode (SMS lebih dari 160 karakter)
+# GSM modem usually can use PDU mode (message can be more than 160 characters).
 pdu_mode = ['C55', 'M55', 'MC60', 'A60', 'MULTIBAND  900E  1800']
 
 # Beberapa modem tidak bisa kirim SMS ke nomor dengan awalan + (international
@@ -38,14 +41,15 @@ sms_dest_without_sign = ['WAVECOM MODEM 800 1900']
 ussd_use_atd = ['C55', 'M55', 'MC60', 'A60', 'TR-800',
     'WAVECOM MODEM 800 1900']
 
-# Modem seperti iTegno W3800 (TR-800) tidak mengenal karakter ENTER "\n"
-# sehingga perlu diganti SPACE " " agar tidak merapat.
+# Modem like iTegno W3800 (TR-800) does not known ENTER char ('\n'),
+# so it will be replace with SPACE char (' ').
 unrecognize_character = { 
     'TR-800': ['\n'],
     }
 
-# External script. Isi dengan command line
+# External script. You can set command line here.
 event = {
     'call': '',
     'sms': '',
     }
+
